<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>PasswordWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="62"/>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="145"/>
        <source>Passwords do not match</source>
        <translation>Passwörter stimmen nicht überein</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="71"/>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation>Der Hinweis ist für alle Benutzer sichtbar. Geben Sie hier nicht das Passwort ein.</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="89"/>
        <source>New Password</source>
        <translation>Neues Passwort</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="111"/>
        <source>Repeat Password</source>
        <translation>Passwort wiederholen</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="119"/>
        <source>Password Hint</source>
        <translation>Passworthinweis</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="128"/>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="129"/>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="130"/>
        <source>Optional</source>
        <translation>Optional</translation>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="78"/>
        <source>Password cannot be empty</source>
        <translation>Passwort darf nicht leer sein</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="79"/>
        <source>Password must have at least %1 characters</source>
        <translation>Passwort muss mindestens %1 Zeichen haben</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="80"/>
        <source>Password must be no more than %1 characters</source>
        <translation>Passwort darf nicht mehr als %1 Zeichen haben</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="81"/>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>Passwort darf nur englische Buchstaben (Groß- und Kleinschreibung beachten), Zahlen oder Sonderzeichen (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/) enthalten</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="82"/>
        <source>No more than %1 palindrome characters please</source>
        <translation>Bitte nicht mehr als %1 Palindrom-Zeichen</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="83"/>
        <source>No more than %1 monotonic characters please</source>
        <translation>Bitte nicht mehr als %1 monotone Zeichen</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="84"/>
        <source>No more than %1 repeating characters please</source>
        <translation>Bitte nicht mehr als %1 sich wiederholende Zeichen</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="85"/>
        <source>The password should differ from the username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="91"/>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>Passwort muss Großbuchstaben, Kleinbuchstaben, Zahlen und Symbole enthalten (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="92"/>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation>Passwort darf nicht mehr als 4 Palindrom-Zeichen enthalten</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="93"/>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="96"/>
        <source>Do not use common words and combinations as password</source>
        <translation>Verwenden Sie keine gebräuchlichen Wörter und Kombinationen als Passwort</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="94"/>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="95"/>
        <source>Create a strong password please</source>
        <translation>Bitte erstellen Sie ein sicheres Passwort</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="102"/>
        <source>It does not meet password rules</source>
        <translation>Es erfüllt nicht die Passwortregeln</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/reset-password-dialog/utils.h" line="72"/>
        <source>It cannot be empty</source>
        <translation>Es darf nicht leer sein</translation>
    </message>
</context>
<context>
    <name>ResetPasswordDialog</name>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="119"/>
        <source>Resetting the password will clear the data stored in the keyring</source>
        <translation>Durch das Zurücksetzen des Passworts werden die im Schlüsselbund gespeicherten Daten gelöscht</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="121"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="177"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="224"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="130"/>
        <source>Security Questions</source>
        <translation>Sicherheitsfragen</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="165"/>
        <source>Reset Password</source>
        <translation>Passwort zurücksetzen</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="166"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="209"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="212"/>
        <source>Next</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="169"/>
        <source>Reset Password By UOS ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="170"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="209"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="212"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="220"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="227"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="176"/>
        <source>Resetting the password will clear the data stored in your keyring, and you should log in again, please save files in advance</source>
        <translation>Wenn Sie das Passwort zurücksetzen, werden die in Ihrem Schlüsselbund gespeicherten Daten gelöscht, und Sie müssen sich erneut anmelden. Bitte speichern Sie Ihre Dateien im Voraus</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="177"/>
        <source>Confirm and Reset</source>
        <translation>Bestätigen und zurücksetzen</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="302"/>
        <source>Successfully reset, please log in and unlock with the new password</source>
        <translation>Erfolgreich zurückgesetzt, bitte anmelden und mit dem neuen Passwort entsperren</translation>
    </message>
</context>
<context>
    <name>SecurityLevelItem</name>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="73"/>
        <source>Weak</source>
        <translation>Schwach</translation>
    </message>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="83"/>
        <source>Medium</source>
        <translation>Mittel</translation>
    </message>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="93"/>
        <source>Strong</source>
        <translation>Stark</translation>
    </message>
</context>
<context>
    <name>SecurityQuestionsWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="126"/>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="127"/>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="128"/>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="130"/>
        <source>What&apos;s the name of the city where you were born?</source>
        <translation>Wie heißt die Stadt, in der Sie geboren wurden?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="131"/>
        <source>What&apos;s the name of the first school you attended?</source>
        <translation>Wie lautet der Name der ersten Schule, die Sie besucht haben?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="132"/>
        <source>Who do you love the most in this world?</source>
        <translation>Wen lieben Sie am meisten auf dieser Welt?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="133"/>
        <source>What&apos;s your favorite animal?</source>
        <translation>Was ist Ihr Lieblingstier?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="134"/>
        <source>What&apos;s your favorite song?</source>
        <translation>Was ist Ihr Lieblingslied?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="135"/>
        <source>What&apos;s your nickname?</source>
        <translation>Was ist Ihr Spitzname?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="185"/>
        <source>Wrong answer</source>
        <translation>Falsche Antwort</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="200"/>
        <source>Keep the answer under 30 characters</source>
        <translation>Beschränken Sie die Antwort auf weniger als 30 Zeichen</translation>
    </message>
</context>
<context>
    <name>UnionIDWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="62"/>
        <source>Phone/Email</source>
        <translation>Telefon/E-Mail</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="68"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="135"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="284"/>
        <source>Get Code</source>
        <translation>Code holen</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="88"/>
        <source>Connecting to the Internet...</source>
        <translation>Mit dem Internet verbinden ...</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="100"/>
        <source>The user account is not linked to UOS ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="113"/>
        <source>Network disconnected, please retry after connected</source>
        <translation>Netzwerkverbindung unterbrochen, bitte versuchen Sie es erneut, wenn die Verbindung wiederhergestellt ist</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="133"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="134"/>
        <source>Required</source>
        <translation>Erforderlich</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="175"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="192"/>
        <source>Phone/Email format is incorrect</source>
        <translation>Telefon-/E-Mail-Format ist falsch</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="246"/>
        <source>System error</source>
        <translation>Systemfehler</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="248"/>
        <source>Login expired, please sign in to the UOS ID again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="250"/>
        <source>Network error</source>
        <translation>Netzwerkfehler</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="252"/>
        <source>You have reached the number limit to get the code today</source>
        <translation>Sie haben die Höchstzahl erreicht, um den Code heute zu erhalten</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="253"/>
        <source>The UOS ID is not linked to a user account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="287"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="329"/>
        <source>Resend (%1s)</source>
        <translation>Erneut senden (%1s)</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="349"/>
        <source>Failed to get the code</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="374"/>
        <source>Wrong verification code</source>
        <translation>Falscher Verifizierungscode</translation>
    </message>
</context>
</TS>